km3pipe.core.Run
================

.. currentmodule:: km3pipe.core

.. autoclass:: Run

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Run.__init__
   
   

   
   
   